Crate arora_module_core

Crate arora_module_core 

Modules

header
resolve

Structs

ImportAsset
Reader
Writer

Enums

ModuleAsset
Assets are records provided or referred to by a module.
ModuleDeclarationError

Functions

analyze_module
Analyzes a module by reading its header and resolves its dependencies with the help of the provided registry. Produces a list of assets that can be used for code generation. First, the types, then the modules, then the imports.
analyze_module_from_path
Analyzes a module from the path where it is written in the YAML format. See analyze_module.