pub enum ModuleAsset {
Type(Uuid, Version, TypeDefinitionFrozen),
Import(ImportAsset),
Module(Uuid, Version, ModuleFrozen, String),
}Expand description
Assets are records provided or referred to by a module.
Variants
Type(Uuid, Version, TypeDefinitionFrozen)
Type, including its identifier.
Import(ImportAsset)
Imported symbol, including the identifier of its origin module.
Module(Uuid, Version, ModuleFrozen, String)
Module, including its identifier, version and executor type.