Modules
Structs
Enums
- Module
Asset - Assets are records provided or referred to by a module.
- Module
Declaration Error
Functions
- analyze_
module - Analyzes a module by reading its header and resolves its dependencies with the help of the provided registry. Produces a list of assets that can be used for code generation. First, the types, then the modules, then the imports.
- analyze_
module_ from_ path - Analyzes a module from the path where it is written in the YAML format.
See
analyze_module.