pub async fn analyze_module<R: ReadableRegistry + Resolver>(
module_definition: ModuleDefinition,
registry: &mut R,
) -> Result<Vec<ModuleAsset>, ModuleDeclarationError>Expand description
Analyzes a module by reading its header and resolves its dependencies with the help of the provided registry. Produces a list of assets that can be used for code generation. First, the types, then the modules, then the imports.